Related efforts and solutions
*****************************

TODO

Related technologies
--------------------

* AWS (NITRC-CE)
* Docker/Packer
* Rocket (CoreOS)
* `NIH Commons computing <https://datascience.nih.gov/commons>`_
* `boutiques <https://github.com/boutiques/schema>`_
* local clusters (CH to meet with UMMS IT)
* `Neuroscience Gateway <http://www.nsgportal.org/>`_
